##
##  rdup.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2022 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         rdup
Summary:      Filesystem Tree Change Discovery Tool
URL:          https://github.com/miekg/rdup
Vendor:       Miek Gieben
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        PLUS
Group:        Filesystem
License:      GPL
Version:      1.1.15
Release:      20220523

#   list of sources
Source0:      https://github.com/miekg/rdup/archive/%{version}.tar.gz
Patch0:       rdup.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, make, autoconf
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  glib, pcre, libarchive, nettle, openssl
PreReq:       glib, pcre, libarchive, nettle, openssl

%description
    rdup(1) is a utility inspired by rsync(1) and the Plan9 way of doing
    backups. rdup(1) itself does not backup anything. It only prints a
    list of files that are changed, or all files in case of a null dump,
    to standard output. Subsequent programs in a pipe line can be used
    to actually implement to backup scheme. After a run a new filelist
    is written. No warning is given when filelist is an existing file,
    it just gets overwritten by rdup. New runs will print out only those
    files that have actually changed since the last run, thereby making
    incremental backups possible.

%track
    prog rdup = {
        version   = %{version}
        url       = https://github.com/miekg/rdup/releases
        regex     = (__VER__)\.tar\.gz
    }

%prep
    %setup -q
    %patch -p0

%build
    autoheader
    autoconf
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags} `pkg-config libarchive --libs-only-L`" \
    LIBS="`pkg-config libarchive --libs-only-l`" \
    ./configure \
        --prefix=%{l_prefix} \
        --mandir=%{l_prefix}/man
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install DESTDIR=$RPM_BUILD_ROOT
    strip $RPM_BUILD_ROOT%{l_prefix}/sbin/* >/dev/null 2>&1 || true
    rmdir $RPM_BUILD_ROOT%{l_prefix}/share/rdup >/dev/null 2>&1 || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

